@@ -134,6 +134,7 @@ define_types("CORECompileToVerilog",
                  ct.c_char_p,  # product
                  ct.c_bool,  # inilne
                  ct.c_bool,  # verilator_debug
+                 ct.c_bool,  # disable-width-cast
              ], ct.c_bool)
 
 libcoreir_c.COREModuleDefGetInterface.argtypes = [COREModuleDef_p]
@@ -406,3 +407,9 @@ libcoreir_c.CORETypeIsOutput.restype = ct.c_bool
 
 libcoreir_c.COREGlobalValueGetNamespace.argtypes = [COREGlobalValue_p]
 libcoreir_c.COREGlobalValueGetNamespace.restype = CORENamespace_p
+
+libcoreir_c.COREGetVersion.argtypes = None
+libcoreir_c.COREGetVersion.restype = ct.c_char_p
+
+libcoreir_c.COREGetRevision.argtypes = None
+libcoreir_c.COREGetRevision.restype = ct.c_char_p
