@@ -59,6 +59,12 @@ class Context:
     def G(self):
         raise Exception("Context.G has been removed, use Context.global_namespace instead")
 
+    def get_version(self):
+        return libcoreir_c.COREGetVersion().decode()
+
+    def get_revision(self):
+        return libcoreir_c.COREGetRevision().decode()
+
     def print_errors(self):
         libcoreir_c.COREPrintErrors(self.context)
 
@@ -186,7 +192,8 @@ class Context:
                                                 namespaces_arr, ct.c_int(len(namespaces)))
 
     def compile_to_verilog(self, top, filename, libs=(), split="",
-                           product="", inline=False, verilator_debug=False):
+                           product="", inline=False, verilator_debug=False,
+                           disable_width_cast=False):
         top = top.ptr
         num_libs = ct.c_int(len(libs))
         libs = (ct.c_char_p * len(libs))(*(lib.encode() for lib in libs))
@@ -195,9 +202,11 @@ class Context:
         product = ct.c_char_p(product.encode())
         inline = ct.c_bool(inline)
         verilator_debug = ct.c_bool(verilator_debug)
+        disable_width_cast = ct.c_bool(disable_width_cast)
         return libcoreir_c.CORECompileToVerilog(self.context, top, filename,
                                                 num_libs, libs, split, product,
-                                                inline, verilator_debug)
+                                                inline, verilator_debug,
+                                                disable_width_cast)
 
     def __del__(self):
         if not self.external_ptr:
